"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const hal = require("../formats/hal");
const service_1 = require("../../principal/service");
class AppController extends controller_1.default {
    async get(ctx) {
        const principalService = new service_1.PrincipalService(ctx.privileges);
        const app = await principalService.findByExternalId(ctx.params.id, 'app');
        const isAdmin = ctx.privileges.has('admin');
        const principalPrivileges = await privilegeService.get(app);
        ctx.response.body = hal.item(app, principalPrivileges.getAll(), isAdmin, await principalService.findGroupsForPrincipal(app));
    }
    async put(ctx) {
        const principalService = new service_1.PrincipalService(ctx.privileges);
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-edit.json');
        const user = await principalService.findByExternalId(ctx.params.id, 'app');
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await principalService.save(user);
        ctx.status = 204;
    }
}
exports.default = new AppController();
//# sourceMappingURL=item.js.map