import Controller from '@curveball/controller';
import { Context } from '@curveball/core';
import { CodeChallengeMethod } from '../types';
import { OAuth2Client } from '../../types';
/**
 * The Authorize controller is responsible for handing requests to the oauth2
 * authorize endpoint.
 *
 * There are 2 oauth2 grant types handled here: 'implicit' and
 * 'authorization_code'. Implicit is disabled by default and will probably
 * be removed from a future version.
 */
declare class AuthorizeController extends Controller {
    get(ctx: Context): Promise<void>;
    tokenRedirect(ctx: Context, oauth2Client: OAuth2Client, params: AuthorizeParamsToken): Promise<void>;
    codeRedirect(ctx: Context, oauth2Client: OAuth2Client, params: AuthorizeParamsCode): Promise<void>;
    /**
     * Redirects to login screen, if login failed
     */
    redirectToLogin(ctx: Context, params: {
        [key: string]: string;
    }): Promise<void>;
}
declare const _default: AuthorizeController;
export default _default;
type AuthorizeParamsDisplay = 'page' | 'popup' | 'touch' | 'wap';
type AuthorizeParamsCode = {
    responseType: 'code' | 'code id_token';
    clientId: string;
    redirectUri?: string;
    scope: string[];
    state?: string;
    codeChallenge?: string;
    codeChallengeMethod?: CodeChallengeMethod;
    nonce?: string;
    display?: AuthorizeParamsDisplay;
};
type AuthorizeParamsToken = {
    responseType: 'token';
    clientId: string;
    redirectUri?: string;
    scope: string[];
    state?: string;
};
