"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const service_1 = require("../../log/service");
const types_1 = require("../../log/types");
const service_2 = require("../../principal/service");
const oauth2Service = require("../service");
class UserAccessTokenController extends controller_1.default {
    async post(ctx) {
        const principalService = new service_2.PrincipalService(ctx.privileges);
        const user = await principalService.findByExternalId(ctx.params.id, 'user');
        if (ctx.auth.equals(user) && !ctx.privileges.has('admin')) {
            throw new http_errors_1.Forbidden('You can only generate OAuth2 access tokens for yourself with this endpoint (unless you have the \'admin\' privilege (which you haven\'t))');
        }
        const token = await oauth2Service.generateTokenDeveloperToken({
            principal: user,
        });
        ctx.response.body = {
            access_token: token.accessToken,
            token_type: token.tokenType,
            expires_in: token.accessTokenExpires - Math.round(Date.now() / 1000),
        };
        (0, service_1.default)(types_1.EventType.generateAccessToken, ctx.ip(), user.id, ctx.request.headers.get('User-Agent'));
    }
}
exports.default = new UserAccessTokenController();
//# sourceMappingURL=user-access-token.js.map