"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const json_1 = require("../../oauth2/formats/json");
const tokenService = require("../service");
const oauth2Service = require("../../oauth2/service");
const oauth2ClientService = require("../../oauth2-client/service");
const service_1 = require("../../principal/service");
class OneTimeTokenExchangeController extends controller_1.default {
    async post(ctx) {
        ctx.privileges.require('a12n:one-time-token:exchange');
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/one-time-token-exchange.json');
        const principalService = new service_1.PrincipalService(ctx.privileges);
        const client = await oauth2ClientService.findByClientId(ctx.request.body.client_id);
        if (!ctx.privileges.isPrincipal(client.app)) {
            throw new http_errors_1.Forbidden(`The client_id ${ctx.request.body.client_id} is not associated with the currently authenticated app`);
        }
        const user = await tokenService.validateToken(ctx.request.body.token, ctx.request.body.dontExpire ?? false);
        if (!user.active) {
            if (ctx.request.body.activateUser) {
                user.active = true;
                await principalService.save(user);
            }
            else {
                throw new http_errors_1.Forbidden('The user associated with the one-time-token has been deactivated. Either activate the user first, or provide the "activateUser" property in the request if the intent is to activate the user with the one-time-token mechanism');
            }
        }
        const oauth2Token = await oauth2Service.generateTokenOneTimeToken({
            client,
            principal: user,
        });
        ctx.response.body = (0, json_1.tokenResponse)(oauth2Token);
    }
}
exports.default = new OneTimeTokenExchangeController();
//# sourceMappingURL=exchange.js.map