import { Context } from '@curveball/core';
import { Principal } from '../types';
import { Privilege, PrivilegeMap, PrivilegeEntry, InternalPrivilege } from './types';
/**
 * Returns all privileges associated with a single principal.
 */
export declare function get(who: Context | Principal | 'insecure'): Promise<LazyPrivilegeBox>;
/**
 * Returns all privileges defined on a single resource.
 */
export declare function findPrivilegesForResource(resource: string): Promise<PrivilegeEntry[]>;
/**
 * Get all the privileges assigned to a principal, excluding privileges
 * the principal inherited by being part of a group.
 */
export declare function getImmediatePrivilegesForPrincipal(principal: Principal): Promise<PrivilegeMap>;
/**
 * Helper class for checking privileges.
 *
 * This class represents the set of privileges for a user.
 * It mostly operates synchronously, but it loads privileges asynchronously.
 *
 * To ensure it's fully loaded await the ready() function.
 */
export declare class LazyPrivilegeBox {
    who: Principal | 'insecure' | 'public';
    privileges: PrivilegeMap | null;
    private init;
    constructor(who: Principal | Context | 'insecure');
    getAll(): PrivilegeMap;
    has(privilege: InternalPrivilege, resource?: string): boolean;
    require(privilege: InternalPrivilege, resource?: string): void;
    /**
     * Await the result of this function to ensure that privleges have been loaded.
     */
    ready(): Promise<void>;
    /**
     * Reloads privileges from the database
     */
    reload(): Promise<PrivilegeMap>;
    /**
     * Returns true if the passed principal matches principal associated with
     * the current set of privileges.
     */
    isPrincipal(principal: Principal): boolean;
}
/**
 * Returns the list of 'privilege types'
 */
export declare function findPrivilegeTypes(): Promise<Privilege[]>;
export declare function findPrivilegeType(privilege: string): Promise<Privilege>;
export declare function replacePrivilegeForUser(user: Principal, privilegeMap: PrivilegeMap): Promise<void>;
export declare function addPrivilegeForUser(user: Principal, privilege: string, resource: string): Promise<void>;
