"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const privilegeService = require("../../privilege/service");
const userHal = require("../formats/hal");
const userService = require("../service");
const service_1 = require("../../principal/service");
class UserController extends controller_1.default {
    async get(ctx) {
        const principalService = new service_1.PrincipalService(ctx.privileges);
        const principal = await principalService.findByExternalId(ctx.params.id, 'user');
        let hasControl = false;
        let hasPassword = false;
        const isAdmin = ctx.privileges.has('admin');
        if (ctx.auth.equals(principal)) {
            hasControl = true;
        }
        else if (isAdmin) {
            hasControl = true;
        }
        if (hasControl && principal.type === 'user') {
            hasPassword = await userService.hasPassword(principal);
        }
        const principalPrivileges = await privilegeService.get(principal);
        const currentUserPrivileges = ctx.privileges;
        ctx.response.body = userHal.item(principal, principalPrivileges.getAll(), hasControl, hasPassword, currentUserPrivileges, await principalService.findGroupsForPrincipal(principal));
    }
    async put(ctx) {
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/principal-edit.json');
        const principalService = new service_1.PrincipalService(ctx.privileges);
        const user = await principalService.findByExternalId(ctx.params.id);
        user.active = !!ctx.request.body.active;
        user.nickname = ctx.request.body.nickname;
        await principalService.save(user);
        ctx.status = 204;
    }
}
exports.default = new UserController();
//# sourceMappingURL=item.js.map